#
# spec file for package equalizer
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

%define soname 180
%define src_name Equalizer
%if 0%{?suse_version} >= 1315 && 0%{?is_opensuse}
%define Leap_verSP 4210
%endif
%if 0%{?suse_version} == 1315
%bcond_without spnav
%endif
# Build with equalizer >= 1.9.0
%if 0%{?suse_version} > 1320 || 0%{?Leap_verSP} == 4210
%bcond_with displaycluster
%endif
%if 0%{?suse_version} <= 1320
%if 0%{?suse_version} >= 1310
%if 0%{?Leap_verSP} != 4210
%bcond_without qt4
%endif
%endif
%endif
Name:           equalizer
Version:        1.8.0
Release:        5.69
Summary:        Middleware to create and deploy parallel OpenGL-based applications
License:        LGPL-2.1 and BSD-3-Clause
Group:          Productivity/Multimedia/Other
Url:            http://equalizergraphics.com/
Source0:        https://github.com/Eyescale/Equalizer/archive/1.8.0.tar.gz#/%{src_name}-%{version}.tar.gz
Source1:        https://github.com/Eyescale/CMake/archive/master.tar.gz#/CMake-common_git20150515.tar.gz
# PATCH-FIX-UPSTREAM flibdir.patch avvissu@yandex.ru -- Fix build on 64-bit
Patch0:         equalizer-1.8.0_libdir.patch
# PATCH-FIX-OPENSUSE include.patch avvissu@yandex.ru -- Remove Buildyard project
Patch1:         equalizer-1.8.0_include.patch
# PATCH-FIX-UPSTREAM doxygen.patch avvissu@yandex.ru -- Fix build error: need administrative privileges
Patch2:         CMake_doxygen.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  pkgconfig
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  pkgconfig(Collage)
BuildRequires:  pkgconfig(Lunchbox)
BuildRequires:  pkgconfig(vmmlib)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(python)
######Recommended Packages######
%if !%{with spnav}
BuildRequires:  libspnav-devel
%endif
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(GLStats)
BuildRequires:  pkgconfig(hwsd) 
%if %{with displaycluster}
BuildRequires:  DisplayCluster-devel
%endif
%if %{with qt4}
BuildRequires:  pkgconfig(QtCore) 
BuildRequires:  pkgconfig(QtGui) 
BuildRequires:  pkgconfig(QtOpenGL)
BuildRequires:  opencv-devel
%endif
#BuildRequires:  libOpenThreads-devel
#BuildRequires:  libOpenSceneGraph-devel
#BuildRequires:  vrpn-devel

%description
Equalizer is the standard middleware to create and deploy parallel 
OpenGL-based applications. It enables applications to benefit from multiple 
graphics cards, processors and computers to scale the rendering 
performance, visual quality and display size. An Equalizer application runs 
unmodified on any visualization system, from a simple workstation to large 
scale graphics clusters, multi-GPU workstations and Virtual Reality 
installations.

%package -n     lib%{name}%{soname}
Summary:        Parallel OpenGL Library
License:        LGPL-2.1 and BSD-3-Clause
Group:          System/Libraries

%description -n lib%{name}%{soname}
Equalizer is the standard middleware to create and deploy parallel 
OpenGL-based applications. It enables applications to benefit from multiple 
graphics cards, processors and computers to scale the rendering 
performance, visual quality and display size. An Equalizer application runs 
unmodified on any visualization system, from a simple workstation to large 
scale graphics clusters, multi-GPU workstations and Virtual Reality 
installations.

%package        devel
Summary:        Development files for %{name}
License:        LGPL-2.1 and BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}
Requires:       pkgconfig(Collage)
Requires:       pkgconfig(GLStats)
Requires:       pkgconfig(Lunchbox)
Requires:       pkgconfig(sm)
Requires:       pkgconfig(vmmlib)
Requires:       pkgconfig(x11)

%description    devel
Middleware to create and deploy parallel OpenGL-based applications.

This package contains header files and libraries needed to develop 
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
Middleware to create and deploy parallel OpenGL-based applications.

API Documentation for Equalizer.

%prep
%setup -q -n %{src_name}-%{version} -a1
mv CMake-common* CMake/common
%patch0 -p1
%patch1 -p1
pushd CMake/common
%patch2 -p1
popd

# Do not compile in DATE and TIME
sed -i '/^HTML_TIMESTAMP/s/YES/NO/' $(grep -rl 'HTML_TIMESTAMP')

%build
%cmake \
	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_SKIP_RPATH:BOOL=OFF \
	-DEQUALIZER_USE_OSG=OFF

make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
%make_install -C build

find %{buildroot} -name 'README.*' -exec rm -f {} \;

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}{%{_datadir}/%{src_name}/doc,%{_docdir}/%{name}}

%fdupes -s %{buildroot}%{_datadir}

%check
#sed -i '/ctest/s|\(bin/ctest\)|\1 -V|' build/Makefile
#make test -C build

%post   -n libequalizer%{soname} -p /sbin/ldconfig

%postun -n libequalizer%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_docdir}/%{name}
%{_bindir}/eqAsync
%{_bindir}/eqHello
%{_bindir}/eqPixelBench
%{_bindir}/eqPly
%{_bindir}/eqPlyConverter
%{_bindir}/eqServer
%{_bindir}/eqThreadAffinity
%{_bindir}/eqWindowAdmin
%{_bindir}/eVolve
%{_bindir}/eVolveConverter
%{_bindir}/seqPly
#%{_bindir}/osgScaleViewer
%{_datadir}/%{src_name}/data
%exclude %{_docdir}/%{name}/API

%files -n libequalizer%{soname}
%defattr(-,root,root)
%{_libdir}/lib%{src_name}*.so.*
%{_libdir}/libSequel.so.*
%{_libdir}/libtriply.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/eq
%{_includedir}/seq
%{_includedir}/triply
%{_libdir}/libEqualizer*.so
%{_libdir}/libSequel.so
%{_libdir}/libtriply.so
# Need for the package bino
%{_libdir}/libGLEW*.a
%{_libdir}/pkgconfig/%{src_name}.pc
%{_datadir}/%{src_name}
%exclude %{_datadir}/%{src_name}/data

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/API

%changelog
* Mon Nov  9 2015 avvissu@yandex.ru
- Build without Qt on openSUSE >= 42.1: required porting to Qt5
* Wed Nov  4 2015 avvissu@yandex.ru
- Build with hwsd on openSUSE > 13.2
* Mon May 18 2015 avvissu@yandex.ru
- Update to 1.8.0:
  * implemented Qt window system for onscreen windows
  * compression is enabled for DisplayCluster streaming
  * DisplayCluster streaming is now asynchronous
  * removed eqConfigTool which was superseded by autoconfig
  * includes various bugfixes
- Add source package CMake-common (Common CMake modules)
- Drop old patches:
  * DoxygenRule.diff
- Add new patches:
  * equalizer-1.8.02_include.patch
  * CMake_doxygen.patch
- Add recommended packages: libspnav-devel qt4-devel
- Use %%%%cmake macro instead of cmake
* Wed May 13 2015 avvissu@yandex.ru
- Add %%%%with_qt5 macro for packages that don't support Qt5:
  * exclude from openSUSE > 13.2: DisplayCluster and hwsd
* Sat May  9 2015 avvissu@yandex.ru
- Drop date-and-time.diff (see a spec file for details)
- Use pkg-config files
- Add BuildRequires: DisplayCluster-devel
- Move data into apps the package and configs into devel
- Spec file cleanup
* Sun Oct  5 2014 avvissu@yandex.ru
- Changed the spec file through spec-cleaner
* Fri Mar 14 2014 avvissu@yandex.ru
- [Fixed] Your file uses  __DATE and __TIME__ this causes the
  package to rebuild when not needed (date-and-time.diff)
* Mon Mar 10 2014 avvissu@yandex.ru
- Recommended Packages:
  * add BuildRequires: DisplayCluster-devel (Software environment for
  large-scale tiled display systems)
* Tue Feb 11 2014 avvissu@yandex.ru
- Recommended Packages:
  * add BuildRequires:  libOpenThreads-devel libOpenSceneGraph-devel
  (High performance 3D graphics toolkit)
* Mon Dec 23 2013 avvissu@yandex.ru
- Recommended Packages:
  * add BuildRequires:  GLStats-devel (Generic OpenGL overlay
  statistics renderer)
* Sat Dec 21 2013 avvissu@yandex.ru
- add static (.a) are needed even for shared builds
* Sat Dec 21 2013 avvissu@yandex.ru
- Update to 1.6.1
- The project broken down into multiple subprojects
- Completely rewritten spec file for building RPM
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build with gcc 4.7
* Mon Apr 23 2012 pascal.bleser@opensuse.org
- update to 1.2.1
- use _service file to download upstream tarballs
* Sun Mar 18 2012 pascal.bleser@opensuse.org
- initial version (1.2)
